@@ -261,18 +261,22 @@ eog_canvas_pixbuf_point (GnomeCanvasItem *item, double x, double y, int cx, int
 	return result;
 }
 
+G_DEFINE_TYPE (EogCanvasPixbuf, eog_canvas_pixbuf, GNOME_TYPE_CANVAS_PIXBUF)
+
 static void
 eog_canvas_pixbuf_finalize (GObject *object)
 {
+	G_OBJECT_CLASS(eog_canvas_pixbuf_parent_class)->finalize(object);
 }
 
 static void
 eog_canvas_pixbuf_dispose (GObject *object)
 {
+	G_OBJECT_CLASS(eog_canvas_pixbuf_parent_class)->dispose(object);
 }
 
 static void
-eog_canvas_pixbuf_instance_init (EogCanvasPixbuf *obj)
+eog_canvas_pixbuf_init (EogCanvasPixbuf *obj)
 {
 }
 
@@ -290,9 +294,3 @@ eog_canvas_pixbuf_class_init (EogCanvasPixbufClass *klass)
 	item_klass->point = eog_canvas_pixbuf_point;
 }
 
-
-GNOME_CLASS_BOILERPLATE (EogCanvasPixbuf,
-			 eog_canvas_pixbuf,
-			 GnomeCanvasPixbuf,
-			 GNOME_TYPE_CANVAS_PIXBUF)
-
