@@ -20,8 +20,7 @@ struct _EogInfoViewPrivate
 	
 };
 
-GNOME_CLASS_BOILERPLATE (EogInfoView, eog_info_view,
-			 GtkNotebook, GTK_TYPE_NOTEBOOK)
+G_DEFINE_TYPE (EogInfoView, eog_info_view, GTK_TYPE_NOTEBOOK)
 
 
 static void
@@ -63,7 +62,7 @@ eog_info_view_class_init (EogInfoViewClass *klass)
 }
 
 static void
-eog_info_view_instance_init (EogInfoView *view)
+eog_info_view_init (EogInfoView *view)
 {
 	EogInfoViewPrivate *priv;
 	GtkWidget *scrwnd;
@@ -109,13 +108,11 @@ update_data_pages_for_image (EogInfoView *view, EogImage *image)
 	g_return_if_fail (EOG_IS_IMAGE (image));
 	
 	eog_info_view_file_show_data (EOG_INFO_VIEW_FILE (view->priv->file_view), image);
-	eog_image_register_infoview (image, EOG_INFO_VIEW_FILE (view->priv->file_view));
 #if HAVE_EXIF
 	{
 		ExifData *ed;
 
 		ed = eog_image_get_exif_information (image);
-		g_print ("Show exif data\n");
 		eog_info_view_exif_show_data (EOG_INFO_VIEW_EXIF (view->priv->exif_view), ed);
 		if (ed != NULL) {
 			gtk_widget_show_all (gtk_widget_get_parent (GTK_WIDGET (view->priv->exif_view)));
