@@ -2,10 +2,10 @@
 #include <gtk/gtk.h>
 #include <glade/glade.h>
 #include <glib/gi18n.h>
+#include <libgnome/gnome-help.h>
 #include "util.h"
 #include "eog-preferences.h"
 #include "eog-config-keys.h"
-#include "eog-hig-dialog.h"
 
 #ifdef G_OS_WIN32
 
@@ -32,28 +32,6 @@ check_toggle_cb (GtkWidget *widget, gpointer data)
 			       NULL);
 }
 
-static void
-check_auto_advance_toggle_cb (GtkWidget *widget, gpointer data)
-{
-	char *key = NULL;
-	GtkWidget *child = NULL;
-	gboolean state = FALSE;
-
-	key = g_object_get_data (G_OBJECT (widget), GCONF_OBJECT_KEY);
-	if (key == NULL) return;
-
-	state = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget));
-	
-	gconf_client_set_bool (GCONF_CLIENT (data),
-			       key, state,			       
-			       NULL);
-	
-	child = g_object_get_data (G_OBJECT (widget), OBJECT_WIDGET);
-	if (child != NULL) {
-		g_object_set (child, "sensitive", state, NULL);
-	}
-}
-
 static void
 spin_button_changed_cb (GtkWidget *widget, gpointer data)
 {
@@ -77,7 +55,7 @@ color_change_cb (GtkColorButton *button, gpointer data)
 
 	gtk_color_button_get_color (button, &color);
 
-	value = g_strdup_printf ("#%2X%2X%2X",
+	value = g_strdup_printf ("#%02X%02X%02X",
 				 color.red / 256,
 				 color.green / 256,
 				 color.blue / 256);
@@ -125,17 +103,16 @@ dialog_response_cb (GtkDialog *dlg, gint res_id, gpointer data)
 		if (error) {
 			GtkWidget *dialog;
 
-			dialog = eog_hig_dialog_new (NULL, GTK_STOCK_DIALOG_ERROR,
-						     _("Could not display help for Eye of GNOME"),
-						     error->message, TRUE);
+			dialog = gtk_message_dialog_new (NULL,
+							 GTK_DIALOG_MODAL,
+							 GTK_MESSAGE_ERROR,
+							 GTK_BUTTONS_OK,
+							 _("Could not display help for Eye of GNOME"));
+			gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
+								  error->message);
 
-			gtk_dialog_add_button (GTK_DIALOG (dialog), GTK_STOCK_OK, GTK_RESPONSE_OK);
-
-			g_signal_connect_swapped (dialog, "response",
-						  G_CALLBACK (gtk_widget_destroy),
-						  dialog);
-
-			gtk_widget_show (dialog);
+			gtk_dialog_run (GTK_DIALOG (dialog));
+			gtk_widget_destroy (dialog);
 			g_error_free (error);
 		}
 		break;
@@ -223,6 +200,7 @@ eog_preferences_show (GtkWindow *parent, GConfClient *client)
 			  "color-set",
 			  G_CALLBACK (color_change_cb),
 			  client);
+	g_free (value);
 
 	/* slideshow page */
 	widget = glade_xml_get_widget (xml, "upscale_check");
@@ -243,16 +221,6 @@ eog_preferences_show (GtkWindow *parent, GConfClient *client)
 			  G_CALLBACK (check_toggle_cb), 
 			  client);
 
-	widget = glade_xml_get_widget (xml, "auto_advance_check");	
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), 
-				      gconf_client_get_bool (client, EOG_CONF_FULLSCREEN_AUTO_ADVANCE, NULL));
-	g_object_set_data (G_OBJECT (widget), OBJECT_WIDGET, glade_xml_get_widget (xml, "seconds_hbox"));
-	g_object_set_data (G_OBJECT (widget), GCONF_OBJECT_KEY, EOG_CONF_FULLSCREEN_AUTO_ADVANCE);
-	g_signal_connect (G_OBJECT (widget), 
-			  "toggled", 
-			  G_CALLBACK (check_auto_advance_toggle_cb), 
-			  client);
-
 	widget = glade_xml_get_widget (xml, "seconds_spin");
 	gtk_spin_button_set_value (GTK_SPIN_BUTTON (widget), 
 				   gconf_client_get_int (client, EOG_CONF_FULLSCREEN_SECONDS, NULL));
@@ -262,11 +230,6 @@ eog_preferences_show (GtkWindow *parent, GConfClient *client)
 			  G_CALLBACK (spin_button_changed_cb), 
 			  client);
 			  
-	if (!gconf_client_get_bool (client, EOG_CONF_FULLSCREEN_AUTO_ADVANCE, NULL)) {
-		widget = glade_xml_get_widget (xml, "seconds_hbox");
-		g_object_set (widget, "sensitive", FALSE, NULL);
-	}
-
 	gtk_window_set_transient_for (GTK_WINDOW (dlg), parent);
 	gtk_widget_show_all (dlg);
 }
